docs

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 10, 2025 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package docs provides utilities for embeding documentation.

Index

Constants

This section is empty.

Variables

var APIs embed.FS

APIs is embedded API documentation.

var GeneralDocumentation embed.FS

GeneralDocumentation is embedded general documentation.

var SchemaAssociations = []cmd.SchemaAssociation{
	{
		Definition: "gnoci.act3-ai.io.schema.json",
	},
}

SchemaAssociations associates the schema file with all config file types.

Functions

func Embedded

func Embedded(root *cobra.Command) *embedutil.Documentation

Embedded is a layout of embedded documentation to surface in the help command and generate in the gendocs command.

func Schemas

func Schemas() fs.FS

Schemas returns the JSON Schema definitions.

Types

This section is empty.

Jump to