Documentation
¶
Overview ¶
Package cmd implements utilities for interpreting, handling, responding to commands sent by Git.
Index ¶
- func HandleCapabilities(ctx context.Context, comm comms.Communicator) error
- func HandleFetch(ctx context.Context, local git.Repository, remote model.ReadOnlyModeler, ...) error
- func HandleList(ctx context.Context, local git.Repository, remote model.Modeler, ...) error
- func HandleOption(ctx context.Context, comm comms.Communicator) error
- func HandlePush(ctx context.Context, local git.Repository, localDir string, ...) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HandleCapabilities ¶
func HandleCapabilities(ctx context.Context, comm comms.Communicator) error
HandleCapabilities executes the capabilities command by listing supported capabilities to Git.
func HandleFetch ¶
func HandleFetch(ctx context.Context, local git.Repository, remote model.ReadOnlyModeler, comm comms.Communicator) error
HandleFetch executes a batch of fetch commands.
func HandleList ¶
func HandleList(ctx context.Context, local git.Repository, remote model.Modeler, comm comms.Communicator) error
HandleList executes the list command. Lists refs one per line.
func HandleOption ¶
func HandleOption(ctx context.Context, comm comms.Communicator) error
HandleOption executes an option command.
func HandlePush ¶
func HandlePush(ctx context.Context, local git.Repository, localDir string, remote model.Modeler, comm comms.Communicator) error
HandlePush executes a batch of push commands.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.